@@ -22,7 +22,7 @@ from calculate.lib.utils.files import FilesError
 from calculate.desktop.desktop import DesktopError
 from calculate.client.client import ClientError
 from calculate.lib.cl_template import TemplatesError
-from calculate.lib.utils.files import isMount
+from calculate.lib.utils.mount import isMount
 
 _ = lambda x: x
 setLocalTranslate('cl_client3', sys.modules[__name__])
